
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json
import model.NeftTransaction
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.OkHttpClient
import okhttp3.Request
import okhttp3.RequestBody.Companion.toRequestBody
import model.TransferTransaction


class TransactionExecutor() {

    private val protocol = "http"
    private val host = "localhost"
    private val port = "3000"
    private val rootRoute = "WESTBANGAL/api"
    private val remoteUrl = "$protocol://$host:$port/$rootRoute"

    fun execute(transactionPair: Pair<TransferTransaction, NeftTransaction>): Boolean {

        val transferTransaction = transactionPair.first
        val neftTransaction = transactionPair.second
        val transferSuccess = execute(Json.encodeToString(transferTransaction))
        if(!transferSuccess) {
            return false
        }
        val neftSuccess = execute(Json.encodeToString(neftTransaction))
        return neftSuccess
    }

    fun execute(postBody: String): Boolean {
        val transferRoute = "IPKSNeftRtgsApiTransfer"
        val transferURL = "$remoteUrl/$transferRoute"
        val jsonMediaType = "application/json; charset=utf-8".toMediaType()

        val httpClient = OkHttpClient()

        val request = Request.Builder()
            .url(transferURL)
            .post(postBody.toRequestBody(jsonMediaType))
            .build()

        httpClient.newCall(request).execute().use { response ->
            if (!response.isSuccessful) {
                return false
            }
            response.body!!.string()
        }

        println("success")
        return true
    }

}